/*
** Job Arranger for ZABBIX
** Copyright (C) 2012 FitechForce, Inc. All Rights Reserved.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

/*
** $Date:: 2012-11-26 13:40:59 +0900 #$
** $Revision: 2728 $
** $Author: ossinfra@FITECHLABS.CO.JP $
**/

#include "common.h"
#include "log.h"
#include "db.h"

#include "javalue.h"
#include "jalog.h"

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
void jarun_set_value_before(const zbx_uint64_t inner_job_id)
{
    zbx_uint64_t inner_jobnet_id;
    DB_RESULT result;
    DB_ROW row;
    const char *__function_name = "jarun_set_value_before";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64, __function_name,
               inner_job_id);
    result =
        DBselect
        ("select inner_jobnet_id, job_id, job_name from ja_run_job_table where inner_job_id = "
         ZBX_FS_UI64, inner_job_id);
    if (NULL != (row = DBfetch(result))) {
        ZBX_STR2UINT64(inner_jobnet_id, row[0]);
        ja_set_value_before(inner_job_id, inner_jobnet_id, "JOB_ID",
                            row[1]);
        ja_set_value_before(inner_job_id, inner_jobnet_id, "JOB_NAME",
                            row[2]);
    } else {
        inner_jobnet_id = 0;
        ja_log("JARUNVALUE300001", inner_jobnet_id, NULL, __function_name,
               inner_job_id);
    }
    DBfree_result(result);

    result =
        DBselect
        ("select jobnet_id, jobnet_name, user_name from ja_run_jobnet_table where inner_jobnet_id = "
         ZBX_FS_UI64, inner_jobnet_id);
    if (NULL != (row = DBfetch(result))) {
        ja_set_value_before(inner_job_id, inner_jobnet_id, "JOBNET_ID",
                            row[0]);
        ja_set_value_before(inner_job_id, inner_jobnet_id, "JOBNET_NAME",
                            row[1]);
        ja_set_value_before(inner_job_id, inner_jobnet_id, "USER_NAME",
                            row[2]);
    } else {
        ja_log("JARUNVALUE300002", inner_jobnet_id, NULL, __function_name,
               inner_job_id);
    }
    DBfree_result(result);
}

/******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *                                                                            *
 * Purpose:                                                                   *
 *                                                                            *
 * Parameters:                                                                *
 *                                                                            *
 * Return value:                                                              *
 *                                                                            *
 * Comments:                                                                  *
 *                                                                            *
 ******************************************************************************/
void jarun_set_value_after(const zbx_uint64_t inner_job_id)
{
    const char *__function_name = "jarun_set_value_after";

    zabbix_log(LOG_LEVEL_DEBUG,
               "In %s() inner_job_id: " ZBX_FS_UI64, __function_name,
               inner_job_id);
    DBexecute
        ("replace into ja_run_value_after_table select * from ja_run_value_before_table"
         " where inner_job_id = " ZBX_FS_UI64, inner_job_id);
}
